# CSV
ingestr supports CSV files as a destination. This allows copying data from any database into a local CSV file.

## URI Format
The URI format for CSV files is as follows:

```plaintext
csv://path/to/csv/file.csv
```
